Usage
Pandoc.convert(f, text, format = "html", open = TRUE, options = "",
footer = TRUE, proc.time, portable.html = TRUE)
Arguments
f
Pandoc's markdown format file path. If URL is provided then the generated file's path is tempfile() but please bear in mind that this way only images with absolute path would shown up in the document.
text
Pandoc's markdown format character vector. Treated as the content of f file - so the f parameter is ignored. The generated file's path is tempfile().
format
required output format. For all possible values here check out Pandoc homepage: http://johnmacfarlane.net/pandoc/
open
try to open converted document with operating system's default program
options
optionally passed arguments to Pandoc (instead of pander's default)
footer
add footer to document with meta-information
proc.time
optionally passed number in seconds which would be shown in the generated document's footer
portable.html
instead of using local files, rather linking JS/CSS files to an online CDN for portability and including base64-encoded images if converting to HTML without custom options