pandoc.horizontal.rule.return: Create horizontal rule
Description
Creates a Pandoc's markdown format horizontal line with trailing and leading newlines.Usage
pandoc.horizontal.rule.return()
Value
- By default this function outputs (see:
cat) the result. If you would want to catch the result instead, then call the function ending in .return.
References
John MacFarlane (2012): _Pandoc User's Guide_. http://johnmacfarlane.net/pandoc/README.html